// WacomServerDevice.h
/*
	Copyright 1999, Be Incorporated.   All Rights Reserved.
	This file may be used under the terms of the Be Sample Code License.
*/

#ifndef WACOM_SERVER_DEVICE_H
#define WACOM_SERVER_DEVICE_H

#include <add-ons/input_server/InputServerDevice.h>
#include <List.h>
#include <String.h>

#include "USBKit.h"

// export this for the input_server
extern "C" _EXPORT BInputServerDevice* instantiate_input_device();
 
class USBDevice;

class WacomServerDevice : public BInputServerDevice, public USBRoster {
 public:
							WacomServerDevice();
	virtual					~WacomServerDevice();

							// BInputServerDevice
	virtual status_t		InitCheck();
	virtual status_t		SystemShuttingDown();

	virtual status_t		Start(const char* device, void* cookie);
	virtual	status_t		Stop(const char* device, void* cookie);
	virtual status_t		Control(const char	*device,
									void		*cookie,
									uint32		code, 
									BMessage	*message);

							// USBRoster
	virtual status_t 		DeviceAdded(USBDevice *dev);
	virtual void 			DeviceRemoved(USBDevice *dev);

							// WacomServerDevice
	inline	bigtime_t		DoubleClickSpeed() const
								{ return fDoubleClickSpeed; }

							// debugging
	inline	BString*		LogString()
								{ return &fLogString; }
			void			LogDataBytes(uchar* data, int bytes);
			void			DumpLogString(const char* path);

private:
			void			_StopAll();

			BList			fTablets;
			bigtime_t		fDoubleClickSpeed;
			bool			fActive;

			// debugging
			BString			fLogString;
};

#endif	// WACOM_SERVER_DEVICE_H
