// WacomTablet.h

/*
	This class encapsulates all info and status about a tablet.
	It runs the thread polling from the USB and sends messages
	to the InputServer.
*/

#ifndef WACOM_TABLET_H
#define WACOM_TABLET_H

#include <Entry.h>

class USBDevice;
class WacomServerDevice;

class WacomTablet {
 public:
								WacomTablet(WacomServerDevice* parent);
	virtual						~WacomTablet();

			status_t			SetTo(USBDevice* device);

			status_t			Start();
			void				Stop();

	inline	bool				IsActive() const
									{ return fActive; }

	inline	int					DataBytes() const
									{ return fDataBytes; }

			status_t			DetectDevice(USBDevice& device);
			status_t			InitDevice(USBDevice& device);

			void				SetDevice(float maxX, float maxY,
										  uint32 mode = DEVICE_INTUOS, 
										  int dataBytes = 10);

			void				ReadData(uchar* data,
										 bool& hasContact,
										 uint32& mode,
										 uint32& buttons,
										 float& x, float& y,
										 float& pressure,
										 int32& clicks,
										 int32& eraser,
										 float& wheelX,
										 float& wheelY,
										 float& tiltX,
										 float& tiltY) const;

			void				SetStatus(uint32 mode,
										  uint32 buttons,
										  float x, float y,
										  float pressure,
										  int32 clicks,
										  uint32 modifiers,
										  int32 eraser,
										  float wheelX,
										  float wheelY,
										  float tiltX = 0.0,
										  float tiltY = 0.0);

			void				SetContact(bool contact);

	inline	USBDevice*			Device() const
									{ return fDevice; }

 private:
	static int32				poll_usb_device(void* arg);

			void				_GetName(USBDevice& device,
										 char** name) const;

	enum {
		DEVICE_UNKOWN,
		DEVICE_PENPARTNER,
		DEVICE_GRAPHIRE,
		DEVICE_INTUOS,
		DEVICE_PL500,
	};
	enum {
		MODE_PEN,
		MODE_MOUSE,
	};

			WacomServerDevice*	fParent;

	volatile bool				fActive;
			thread_id			fThreadID;
			USBDevice*			fDevice;

			// device specific settings
			uint32				fDeviceMode;
			float				fMaxX;
			float				fMaxY;
			int					fDataBytes;

			float				fPosX;
			float				fPosY;
			float				fFakeMouseX;
			float				fFakeMouseY;
			uint32				fButtons;
			float				fPressure;
			uint32				fModifiers;
			bool				fEraser;
			float				fTiltX;
			float				fTiltY;
			float				fWheelX;
			float				fWheelY;
			bigtime_t			fLastClickTime;
			int32				fClicks;
			bool				fHasContact;

			float				fJitterX;
			float				fJitterY;
};

#endif	// WACOM_TABLET_H
